#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
## "Restricted Materials of IBM"
## 5724-O98
## (c)  Copyright IBM Corp. 2011 All Rights Reserved.
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with
## IBM Corp.
#############################################################################
##
##   Title:	EnginePostInstallConfigure_3.0.0.1.sh
##   Description: Handles the post install configure actions for the 
##                TS_Engine_3.0.0.1 IU
##   usage:  EnginePostInstallConfigure_3.0.0.1.sh -ts_home <install location>
##
#############################################################################
# include the RFIDIC environment settings
scriptDir=`dirname $0`
if [ -n "$RFIDIC_HOME" -a -d $RFIDIC_HOME"/bin" ];then
  . ${RFIDIC_HOME}/bin/utils.sh
else
  . ${scriptDir}/utils.sh
fi

usage()
{
	echo "	USAGE: ./EnginePostInstallConfigure_3.0.0.1.sh"
	echo "                          [-ts_home=<TS install location>]"
	echo "                          [-was_admin_user=<WAS admin password>]"
	echo "                          [-was_admin_password=<WAS admin password>]"
	echo "                          [-ws_user=<web services password>]"
	echo "                          [-ws_password=<web services password>]"
	echo "                          [-tsConfigured=[true/false]]"
	echo "                          [-action=[rollback/update]]"
}

copyFiles()
{
    # if these files exist then this is not a new install
    #  it could be an update or a rollback
    #  if there is a backup file, then its a rollback and we must restore the backup file
    #  if no backup file, then do nothing
	if [ -f "$ts_home/etc/RFIDICServer.xml" ];then
		if [ -f "$ts_home/etc/RFIDICServer.xml_3000" ];then
			mv -f "$ts_home/etc/RFIDICServer.xml_3000" "$ts_home/etc/RFIDICServer.xml"
		fi
	# if RFIDICServer.xml is not there, then its a new install and do the copy
	else
		cp -f "$ts_home/reserved/RFIDICServer.xml" "$ts_home/etc/RFIDICServer.xml"
	fi
	
	if [ -f "$ts_home/etc/log.xml" ];then
		if [ -f "$ts_home/etc/log.xml_3000" ];then
			mv -f "$ts_home/etc/log.xml_3000" "$ts_home/etc/log.xml"
		fi
	# if log.xml is not there, then its a new install and do the copy
	else
		cp -f "$ts_home/reserved/log.xml" "$ts_home/etc/log.xml"
	fi
	
	if [ -f "$ts_home/bin/tsEnv.sh" ];then
		if [ -f "$ts_home/bin/tsEnv.sh_3000" ];then
			mv -f "$ts_home/bin/tsEnv.sh_3000" "$ts_home/bin/tsEnv.sh"
		fi
	# if tsEnv.sh is not there, then its a new install and do the copy
	else
		cp -f "$ts_home/reserved/tsEnv.sh" "$ts_home/bin/tsEnv.sh"
	fi
			
}

updateTSEnv()
{
    sed 's#read -p "$msg" DBMS_ADMIN_USER#read DBMS_ADMIN_USER#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
    if [ "$?" -eq "0" ];then
        mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
    fi

    sed 's#read -s -p "$msg" DBMS_ADMIN_PASSWORD#stty -echo\
                read DBMS_ADMIN_PASSWORD\
                stty echo#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
    if [ "$?" -eq "0" ];then
        mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
    fi

    sed 's#PCKS12#PKCS12#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
    if [ "$?" -eq "0" ];then
        mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
    fi

    # If this line is already present in the file, then a previous update has made the changes. 
    grep "if \[ -z \"\$TS_ADMIN_GROUP\" \]\;then" $ts_home/bin/tsEnv.sh

    if [ "$?" -ne "0" ];then
        sed '/TS_ADMIN_USER\=/ i\
if \[ -z \"\$TS_ADMIN_USER\" \]\;then' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed '/TS_ADMIN_GROUP\=/ i\
fi \
\
if \[ -z \"\$TS_ADMIN_GROUP\" \]\;then' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed '/export TS_ADMIN_GROUP/ a\
fi' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi
    fi

# Check if change to asciiUpdate as already been done
    grep "sedReturnCode" $ts_home/bin/tsEnv.sh
    if [ "$?" -ne "0" ];then
        sed '/run_command mv \-f \$1\.tmp \$1/ i\
\ \ \ \ sedReturnCode\=\$\? \
\
    if \[ \$\? \-eq 0 \]\;then' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed '/run_command mv \-f \$1\.tmp \$1/ a\
\ \ \ \ else \
        rm \-f \$1\.tmp \
    fi' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed '/unset replaceStr/ a\
    return $sedReturnCode' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi
    fi

    
    # Check for RFIDIC_FILE_STORE update has already been done
    grep "RFIDIC_FILE_STORE=" $ts_home/bin/tsEnv.sh
    if [ "$?" -ne "0" ];then
        sed '/RFIDIC_BUS_NAME\=/ a\
fi \
if \[ -z \"\$RFIDIC_FILE_STORE\" \]\;then \
    RFIDIC_FILE_STORE\=\$TS_HOME\/MEDATA' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$   
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi          
    fi

    # Check if oraVersion is already part of the properties
    grep "partial_MQ_LSR_PORT oraVersion" $ts_home/bin/tsEnv.sh
    if [ "$?" -ne "0" ];then
        sed '/ORACLE_JDBC_URL\=/ a\
        oraVersion\=\"11g\"' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed '/export ORACLE_JDBC_URL/ a\
        export oraVersion' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's/partial_MQ_HOST partial_MQ_LSR_PORT\"/partial_MQ_HOST partial_MQ_LSR_PORT oraVersion\"/' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi
    fi

    # Check to see if the prependToPath/appendToPath update has already been done
    grep "appendToPath()" $ts_home/bin/tsEnv.sh
    if [ "$?" -ne "0" ];then
        sed '/getMessageClasspath()/ i\
appendToPath() \
{ \
pathName=\$1 \
pathVariable=\"\$\"\$1 \
newVar=\$2 \
\
found=`eval \$ECHO \$pathVariable | eval grep \$newVar` \
if \[ -z \"\$found\" \]; then \
\#\$ECHO \"Adding \$newVar to \$pathVariable\" \
eval \$pathName=\$pathVariable:$newVar \
fi \
} \
prependToPath() \
{ \
pathName=\$1 \
pathVariable=\"\$\"\$1 \
newVar=\$2 \
\
found=`eval \$ECHO \$pathVariable | eval grep \$newVar` \
if \[ -z \"\$found\" \]; then \
\#\$ECHO \"Adding \$newVar to \$pathVariable\" \
eval \$pathName=\$newVar:\$pathVariable \
fi \
} \ ' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$

        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#if \[ -n  \"\$pathdone\" \]\; then#prependToPath PATH $JAVA_HOME/bin#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#log "PATH = $PATH"#prependToPath PATH $TS_HOME/bin#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed -f $ts_home/bin/sedTSEnv $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#CLASSPATH=$CLASSPATH:$i#appendToPath CLASSPATH $i#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#PATH=.:$JAVA_HOME/bin:$TS_HOME/bin:$MQ_HOME/bin:$DBMS_HOME/bin:$WAS_HOME/bin:$PATH#PATH=.:$PATH#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#CLASSPATH=$CLASSPATH:$MQ_LIB_PATH/com.ibm.mqjms.jar:$MQ_LIB_PATH/com.ibm.mq.jar:$WAS_HOME/lib/j2ee.jar#appendToPath CLASSPATH $MQ_LIB_PATH/com.ibm.mqjms.jar \
appendToPath CLASSPATH $MQ_LIB_PATH/com.ibm.mq.jar \
appendToPath CLASSPATH $WAS_HOME/lib/j2ee.jar \ #' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#CLASSPATH=$CLASSPATH:$DBMS_JDBC_LIB_PATH/ojdbc5.jar#appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/ojdbc5.jar#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#CLASSPATH=$CLASSPATH:$DBMS_JDBC_LIB_PATH/db2jcc.jar:$DBMS_JDBC_LIB_PATH/db2jcc_javax.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar:$DBMS_JDBC_LIB_PATH/db2jcc_license_cisuz.jar#appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc.jar \
appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_javax.jar \
appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_license_cu.jar \
appendToPath CLASSPATH $DBMS_JDBC_LIB_PATH/db2jcc_license_cisuz.jar#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$ 
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi

        sed 's#\tpathdone=yes# \
log "PATH = $PATH"#' $ts_home/bin/tsEnv.sh > $ts_home/bin/1.$$
        if [ "$?" -eq "0" ];then
            mv -f $ts_home/bin/1.$$ $ts_home/bin/tsEnv.sh
        fi
    fi

    chmod 750 $ts_home/bin/tsEnv.sh
}

#### Main starts here ####
#### Input Arguments Verification #####		
for item in $*
	do
		if [ `expr match "$item" '-ts_home='` != 0 ];then
			ts_home=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-tsConfigured='` != 0 ];then
			tsConfigured=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_user='` != 0 ];then
			was_admin_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ];then
			was_admin_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ws_user='` != 0 ];then
			ws_user=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-ws_password='` != 0 ];then
			ws_password=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		elif [ `expr match "$item" '-action='` != 0 ];then
			action=`$ECHO $item | $AWK_EQUAL '{print($2)}'`
		else
			usage
			exit 1
		fi
	done

### Setup the log file
logFileName=TSUpdateLog_`date "+%Y%m%d%H%M%S"`
assignLogFile ${scriptDir}/../logs/$logFileName

### Copy user modifiable files if necessary
copyFiles >> $utilsLogFile 2>&1
	
### Update the tsEnv.sh file contents
updateTSEnv >> $utilsLogFile 2>&1

### Remove compiled jython classes to force recompilation of any changed jython
rm -f $ts_home/bin/jython/*.class

createProfRetCode=0
updateTSRetCode=0
updateDB=0
retCode=0

echo "action: $action"
echo "tsConfigured: $tsConfigured"
echo "was_admin_user: $was_admin_user"
###echo "was_admin_password: $was_admin_password"
echo "ws_user: $ws_user"
###echo "ws_password: $ws_password"

### Call createUserProfile to set permissions
echo "Setting permissions"
$ts_home/bin/createUserProfile.sh -SET_PERMISSIONS_ONLY >> $utilsLogFile 2>&1
createProfRetCode=$?
if [ "$createProfRetCode" -eq "0" ];then
	echo "-------- Permissions have been successfully set --------"
	log "-------- Permissions have been successfully set --------"
fi

#Call updateTS.sh only when its an "update" action and TS has already been configured
if [ "$action" = "update" -a "$tsConfigured" = "true" ];then
	echo "-------- Updating TS --------"
	log "-------- Updating TS --------"
	$ts_home/bin/updateTS.sh -was_admin_user=$was_admin_user -was_admin_password=$was_admin_password \
          -ws_user=$ws_user -ws_password=$ws_password -log=$utilsLogFile
	updateTSRetCode=$?

	echo "-------- Updating database schema --------"
	log "-------- Updating database schema --------"
	$ts_home/bin/deployMetadata.sh -migrate -was_admin_user=wsadmin -was_admin_password=was4me \
          -force_restart_apps >> $utilsLogFile 2>&1
	updateDB=$?
	if [ "$updateDB" -eq "0" ];then
		echo "-------- The database schema has been updated --------"
		log "-------- The database schema has been updated --------"
	else
		echo "--- The database schema failed to update ---"
		log "--- The database schema failed to update ---"
	
	fi
fi

if [ "$createProfRetCode" -ne "0" ];then	
    retCode=$createProfRetCode
elif [ "$updateTSRetCode" -ne "0" ];then
    retCode=$updateTSRetCode
elif [ "$updateDB" -ne "0" ];then
    retCode=$updateDB
fi

if [ "$retCode" -eq "0" ];then
	echo "-------- Script completed successfully --------"
	log "-------- Script completed successfully --------"
else
	echo "-------- Script did not complete successfully --------"
	log "-------- Script did not complete successfully --------"
fi

exit $retCode