#!/bin/sh
#
# Deployment script for Traceability Server files to rebrand Cognos installation 
#
# -------------------------------------------------------------------
# Functions
# -------------------------------------------------------------------
function deploy_ts_files()
{
  echo Creating directory for Tracebaility Server image files ...
  
  if ! [ -d "$1/webcontent/skins/corporate/branding_ts/" ]; then 
    mkdir $1/webcontent/skins/corporate/branding_ts 
  else 
    echo Directory already exists. 
  fi
     
  echo Deploying Traceability Server files ...
  cp ../new_files/webcontent/skins/corporate/branding_ts/its_prodname_swoosh_menu.bmp $1/webcontent/skins/corporate/branding_ts/
  cp ../new_files/webcontent/skins/corporate/branding_ts/its_prodname_swoosh.bmp      $1/webcontent/skins/corporate/branding_ts/
  cp ../new_files/webcontent/skins/corporate/branding_ts/welcome_qt_background.bmp    $1/webcontent/skins/corporate/branding_ts/
  cp ../new_files/webcontent/skins/corporate/shared/banner.css                        $1/webcontent/skins/corporate/shared
  cp ../new_files/webcontent/skins/corporate/viewer/CRN.css                           $1/webcontent/skins/corporate/viewer/
  cp ../new_files/webcontent/skins/corporate/qs/CRN.css                               $1/webcontent/skins/corporate/qs/
  cp ../new_files/webcontent/skins/corporate/ags/crn.css                              $1/webcontent/skins/corporate/ags/
  cp ../new_files/webcontent/skins/corporate/ans/background.css                       $1/webcontent/skins/corporate/ans/
  cp ../new_files/webcontent/skins/corporate/hal/hal_skin_corporate.css               $1/webcontent/skins/corporate/hal/
  cp ../new_files/webcontent/skins/corporate/portal/default.css                       $1/webcontent/skins/corporate/portal/
  cp ../new_files/webapps/p2p/WEB-INF/css/skins/corporate.xml                         $1/webapps/p2p/WEB-INF/css/skins/
}

function backup_original_files()
{
  echo Backing up original files ...
  cp $1/webcontent/skins/corporate/shared/banner.css               $1/webcontent/skins/corporate/shared/banner.css.old
  cp $1/webcontent/skins/corporate/viewer/CRN.css                  $1/webcontent/skins/corporate/viewer/CRN.css.old
  cp $1/webcontent/skins/corporate/qs/CRN.css                      $1/webcontent/skins/corporate/qs/CRN.css.old
  cp $1/webcontent/skins/corporate/ags/crn.css                     $1/webcontent/skins/corporate/ags/crn.css.old
  cp $1/webcontent/skins/corporate/ans/background.css              $1/webcontent/skins/corporate/ans/background.css.old
  cp $1/webcontent/skins/corporate/hal/hal_skin_corporate.css      $1/webcontent/skins/corporate/hal/hal_skin_corporate.css.old
  cp $1/webcontent/skins/corporate/portal/default.css              $1/webcontent/skins/corporate/portal/default.css.old
  cp $1/webapps/p2p/WEB-INF/css/skins/corporate.xml                $1/webapps/p2p/WEB-INF/css/skins/corporate.xml.old
}
  
function error_wrong_parm()
{
  echo Incorrect Cognos 10 BI Connection Server installation directory provided. 
  echo Specify the directory where Cognos 10 BI Connection Server is installed. 
  echo Usage:
  echo "   deploy_ts_files.sh [Cognos 10 BI Connection Server installation directory]"
  echo "   Example: deploy_ts_files.sh /opt/cognos/c10"
}

# -------------------------------------------------------------------
# Start script.
# -------------------------------------------------------------------
echo ----------------------------
echo Start of deployement script.
echo ----------------------------

# -------------------------------------------------------------------
# Don't proceed if the input parameter is incorrect.
# This is tested by checking if the webcontent/skins directory exists.
# -------------------------------------------------------------------
if ! [ -d "$1/webcontent/skins" ]; then 
  error_wrong_parm

else
  # -------------------------------------------------------------------
  # If the file are not already backed up, backup the existing branding  
  # files for the Corporate style and deploy the new files.
  # -------------------------------------------------------------------
  if ! [ -f "$1/webapps/p2p/WEB-INF/css/skins/corporate.xml.old" ]; then 
    backup_original_files $1
    deploy_ts_files $1 
  else 
    echo Traceability Server files are already deployed.
  fi
fi 

echo -------------------------
echo End of deployment script.
echo -------------------------
