-- These views are created within the RCM data mart that is
-- created by Data Manager


--
-- RCMSCHEMA.RCM_VOCAB_CONFIG_VW
--
CREATE  VIEW  "RCMSCHEMA"."RCM_VOCAB_CONFIG_VW" AS
SELECT "RCM_KEYWORD", "VOCABULARY", "ALIAS"
FROM "RCMSCHEMA"."RCM_VOCAB_CONFIG";


--
-- RCMSCHEMA.CURRENT_DATE_BY_LOC_VW
--
CREATE VIEW "RCMSCHEMA"."CURRENT_DATE_BY_LOC_VW" AS
SELECT	TZ_NAME, TZ_OFFSET, CURR_TIMESTAMP, CURR_DATE
FROM "RCMSCHEMA"."CURRENT_DATE_BY_LOC";


--
-- RCMSCHEMA.LOCATION_VW
--
CREATE VIEW RCMSCHEMA.LOCATION_VW (internal_id, external_id, vocabulary,
       	name, company, gln, sslt, sslta, ssltae, street1, street2, city,
	stateOrRegion, postalCode, country, business_type, location_type,
	timezoneoffset, storage_loc_type, supplier_loc_type, owner_loc_type) AS
SELECT internal_id, external_id, vocabulary, name, company, gln, sslt,
        sslta, ssltae, street1, street2, city, stateorregion, postalcode,
        country, businesstype, locationtype, timezoneoffset, storage_loc,
	supplier_loc, owner_loc
FROM RCMSCHEMA.LOCATION;


--
-- RCMSCHEMA.VOCABULARY_ELEMENT_VW
--
CREATE VIEW RCMSCHEMA.VOCABULARY_ELEMENT_VW AS
SELECT internal_id, name, vocabulary_id, vocabulary, entity
FROM rcmschema.vocabulary_element;


--
-- RCMSCHEMA.EVENT_VW
--
CREATE VIEW RCMSCHEMA.EVENT_VW (EVENT_ID, EPC, SIID_STATE, TYPE, eventTime, recordTime,
eventTimeZoneOffset_id, bizStep_id, bizStep, disposition_id, disposition, readPoint_id,
readPoint, bizLocation_id, bizLocation, shipToBusinessLocationCode_id, shipToBusinessLocationCode,
shipToPhysicalLocationCode_id, shipToPhysicalLocationCode, shipFromBusinessLocationCode_i,
shipFromBusinessLocationCode, shipFromPhysicalLocCode_id,
shipFromPhysicalLocCode, assetType) AS

SELECT
	EVENT_ID,
	SERIAL_ID,
	SIID_STATE_NAME,
	EVENT_TYPE,
	EVENT_TIME,
	RECORD_TIME,
	TIME_ZONE_OFFSET,
	BIZ_STEP,
	BIZ_STEP_NAME,
	DISPOSITION,
	DISPOSITION_NAME,
	READ_POINT,
	READ_POINT_NAME,
	BIZ_LOCATION,
	BIZ_LOCATION_NAME,
	RECIPIENT_ID,
	RECIPIENT_NAME,
	RECIPIENT_SITE_ADDRESS,
	RECIPIENT_SITE_ADDR_NAME,
	SENDER_ID,
	SENDER_NAME,
	SENDER_SITE_ADDRESS,
	SENDER_SITE_ADDR_NAME,
	ASSET_TYPE
FROM
	RCMSCHEMA.TNT_SI_EVENTS;


--
-- RCMSCHEMA.PRODUCT_VW
--
CREATE VIEW RCMSCHEMA.PRODUCT_VW (internal_id, external_id, vocabulary, assetName, description) AS 
SELECT internal_id, external_id, vocabulary, assettypename as assetName, description
FROM rcmschema.product;


--
-- RCMSCHEMA.DATE_DIM_VW
--
CREATE VIEW RCMSCHEMA.DATE_DIM_VW
 (DATE_ID,YEAR_NBR,QTR_NBR,QTR_NAME,MONTH_NBR,MONTH_NAME,DAY_NBR,WEEK_DAY_NBR,DAY_NAME,BUSINESS_DAY) AS SELECT d.DATE_ID AS DATE_ID, d.YEAR_NBR AS YEAR_NBR, d.QTR_NBR AS QTR_NBR, d.QTR_NAME AS QTR_NAME, d.MONTH_NBR AS MONTH_NBR, d.MONTH_NAME AS MONTH_NAME, d.DAY_NBR AS DAY_NBR, d.WEEK_DAY_NBR AS WEEK_DAY_NBR, d.DAY_NAME AS DAY_NAME, d.BUSINESS_DAY AS WEEK_DAY_FLAG FROM RCMSCHEMA.DATE_DIM d;


--
-- RCMSCHEMA.TARGET_VW
--
-- THIS SQL CREATES THE TARGET_VW VIEW THAT IS USED IN THE BI APPLICATION
-- THE VIEW IS SOURCED BY THE ABOVE TARGET TABLES.  THE METRICS USE THE COALESCE FUNCTION TO RETURN METRIC AT -- THE LOWEST POSSIBLE GRAIN.

CREATE VIEW RCMSCHEMA.TARGET_VW 
( 
COMPANY, NAME, 
LOCATION_ID, 
PRODUCT_ID, 
ASSET_NAME, 
TARGET_DAILY_INVENTORY, 
DAILY_INV_LO_THRES_PERC,
DAILY_INV_HI_THRES_PERC, 
TARGET_DAYS_IN_INVENTORY,
DAYS_IN_INV_HI_THRES_PERC,
TARGET_AL_CYCLE_TIME,
AL_CYCLE_TIME_LO_THRES_PERC,
AL_CYCLE_TIME_HI_THRES_PERC,
AL_CYCLE_TIME_LO_RATIO,
AL_CYCLE_TIME_HI_RATIO,
TARGET_BP_CYCLE_TIME,
BP_CYCLE_TIME_LO_THRES_PERC,
BP_CYCLE_TIME_HI_THRES_PERC,
BP_CYCLE_TIME_LO_RATIO,
BP_CYCLE_TIME_HI_RATIO,
TARGET_DWELL_TIME,
DWELL_TIME_LO_THRES_PERC,
DWELL_TIME_HI_THRES_PERC,
DWELL_TIME_LO_RATIO,
DWELL_TIME_HI_RATIO
) AS 
SELECT 
TARGET_BUSINESS.COMPANY, 
TARGET_BUSINESS_LOCATION.NAME, 
TARGET_BUS_LOCATION_PROD.LOCATION_ID, 
TARGET_BUS_LOCATION_PROD.PRODUCT_ID, 
TARGET_BUS_LOCATION_PROD.ASSET_NAME, 
coalesce(TARGET_BUS_LOCATION_PROD.TARGET_DAILY_INVENTORY,TARGET_BUSINESS_LOCATION.TARGET_DAILY_INVENTORY, TARGET_BUSINESS.TARGET_DAILY_INVENTORY) TARGET_DAILY_INVENTORY, 
coalesce(TARGET_BUS_LOCATION_PROD.DAILY_INV_LO_THRES_PERC, TARGET_BUSINESS_LOCATION.DAILY_INV_LO_THRES_PERC, TARGET_BUSINESS.DAILY_INV_LO_THRES_PERC) DAILY_INV_LO_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.DAILY_INV_HI_THRES_PERC, TARGET_BUSINESS_LOCATION.DAILY_INV_HI_THRES_PERC, TARGET_BUSINESS.DAILY_INV_HI_THRES_PERC) DAILY_INV_HI_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.TARGET_DAYS_IN_INVENTORY,TARGET_BUSINESS_LOCATION.TARGET_DAYS_IN_INVENTORY , TARGET_BUSINESS.TARGET_DAYS_IN_INVENTORY  ) TARGET_DAYS_IN_INVENTORY, 
coalesce(TARGET_BUS_LOCATION_PROD.DAYS_IN_INV_HI_THRES_PERC,TARGET_BUSINESS_LOCATION.DAYS_IN_INV_HI_THRES_PERC, TARGET_BUSINESS.DAYS_IN_INV_HI_THRES_PERC) DAYS_IN_INV_HI_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.TARGET_AL_CYCLE_TIME,TARGET_BUSINESS_LOCATION.TARGET_AL_CYCLE_TIME , TARGET_BUSINESS.TARGET_AL_CYCLE_TIME  ) TARGET_AL_CYCLE_TIME, 
coalesce(TARGET_BUS_LOCATION_PROD.AL_CYCLE_TIME_LO_THRES_PERC, TARGET_BUSINESS_LOCATION.AL_CYCLE_TIME_LO_THRES_PERC , TARGET_BUSINESS.AL_CYCLE_TIME_LO_THRES_PERC) AL_CYCLE_TIME_LO_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.AL_CYCLE_TIME_HI_THRES_PERC,TARGET_BUSINESS_LOCATION.AL_CYCLE_TIME_HI_THRES_PERC, TARGET_BUSINESS.AL_CYCLE_TIME_HI_THRES_PERC) AL_CYCLE_TIME_HI_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.AL_CYCLE_TIME_LO_RATIO , TARGET_BUSINESS_LOCATION.AL_CYCLE_TIME_LO_RATIO  , TARGET_BUSINESS.AL_CYCLE_TIME_LO_RATIO ) AL_CYCLE_TIME_LO_RATIO, 
coalesce(TARGET_BUS_LOCATION_PROD.AL_CYCLE_TIME_HI_RATIO ,TARGET_BUSINESS_LOCATION.AL_CYCLE_TIME_HI_RATIO,TARGET_BUSINESS.AL_CYCLE_TIME_HI_RATIO) AL_CYCLE_TIME_HI_RATIO,
coalesce(TARGET_BUS_LOCATION_PROD.TARGET_BP_CYCLE_TIME,TARGET_BUSINESS_LOCATION.TARGET_BP_CYCLE_TIME , TARGET_BUSINESS.TARGET_BP_CYCLE_TIME  ) TARGET_BP_CYCLE_TIME, 
coalesce(TARGET_BUS_LOCATION_PROD.BP_CYCLE_TIME_LO_THRES_PERC, TARGET_BUSINESS_LOCATION.BP_CYCLE_TIME_LO_THRES_PERC , TARGET_BUSINESS.BP_CYCLE_TIME_LO_THRES_PERC) BP_CYCLE_TIME_LO_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.BP_CYCLE_TIME_HI_THRES_PERC,TARGET_BUSINESS_LOCATION.BP_CYCLE_TIME_HI_THRES_PERC, TARGET_BUSINESS.BP_CYCLE_TIME_HI_THRES_PERC) BP_CYCLE_TIME_HI_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.BP_CYCLE_TIME_LO_RATIO , TARGET_BUSINESS_LOCATION.BP_CYCLE_TIME_LO_RATIO  , TARGET_BUSINESS.BP_CYCLE_TIME_LO_RATIO ) BP_CYCLE_TIME_LO_RATIO, 
coalesce(TARGET_BUS_LOCATION_PROD.BP_CYCLE_TIME_HI_RATIO ,TARGET_BUSINESS_LOCATION.BP_CYCLE_TIME_HI_RATIO,TARGET_BUSINESS.BP_CYCLE_TIME_HI_RATIO) BP_CYCLE_TIME_HI_RATIO,
coalesce(TARGET_BUS_LOCATION_PROD.TARGET_DWELL_TIME,TARGET_BUSINESS_LOCATION.TARGET_DWELL_TIME , TARGET_BUSINESS.TARGET_DWELL_TIME  ) TARGET_DWELL_TIME, 
coalesce(TARGET_BUS_LOCATION_PROD.DWELL_TIME_LO_THRES_PERC, TARGET_BUSINESS_LOCATION.DWELL_TIME_LO_THRES_PERC , TARGET_BUSINESS.DWELL_TIME_LO_THRES_PERC) DWELL_TIME_LO_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.DWELL_TIME_HI_THRES_PERC,TARGET_BUSINESS_LOCATION.DWELL_TIME_HI_THRES_PERC, TARGET_BUSINESS.DWELL_TIME_HI_THRES_PERC) DWELL_TIME_HI_THRES_PERC, 
coalesce(TARGET_BUS_LOCATION_PROD.DWELL_TIME_LO_RATIO , TARGET_BUSINESS_LOCATION.DWELL_TIME_LO_RATIO  , TARGET_BUSINESS.DWELL_TIME_LO_RATIO ) DWELL_TIME_LO_RATIO, 
coalesce(TARGET_BUS_LOCATION_PROD.DWELL_TIME_HI_RATIO ,TARGET_BUSINESS_LOCATION.DWELL_TIME_HI_RATIO,TARGET_BUSINESS.DWELL_TIME_HI_RATIO) DWELL_TIME_HI_RATIO
FROM (RCMSCHEMA.TARGET_BUS_LOCATION_PROD TARGET_BUS_LOCATION_PROD 
LEFT JOIN RCMSCHEMA.TARGET_BUSINESS_LOCATION TARGET_BUSINESS_LOCATION ON TARGET_BUS_LOCATION_PROD.LOCATION_ID = TARGET_BUSINESS_LOCATION.LOCATION_ID) 
LEFT JOIN RCMSCHEMA.TARGET_BUSINESS TARGET_BUSINESS ON TARGET_BUSINESS_LOCATION.COMPANY = TARGET_BUSINESS.COMPANY;



--
-- RCMSCHEMA.EVENT_EPC_VW
--
CREATE VIEW "RCMSCHEMA"."EVENT_EPC_VW" (
		  "EVENT_ID", 
		  "BIZLOC_UTC_TIME" , 
		  "BIZLOC_UTC_DATE" , 
		  "BIZLOC_TIME_OFFSET" , 
		  "BIZLOC_LOCAL_TIME" , 
		  "BIZLOC_LOCAL_DATE" , 
		  "INVENTORY_TIME_OFFSET" , 
		  "INVENTORY_LOCAL_TIME" , 
		  "INVENTORY_LOCAL_DATE" , 
		  "RECORDTIME",
		  "PRODUCT_ID",
		  "ASSET_NAME",
		  "EPC",
		  "ACTION_ID",
		  "ACTION",
		  "BIZSTEP_ID",
		  "BIZSTEP",
		  "DISPOSITION_ID",
		  "DISPOSITION",
		  "READ_POINT_ID",
		  "READ_POINT",
		  "BIZ_LOCATION_ID",
		  "BIZ_LOCATION",
		  "INVENTORY_LOCATION_ID",
		  "INVENTORY_LOCATION",
		  "SHIP_FROM_BUS_LOCATION_CODE_ID", 
		  "SHIP_FROM_BUS_LOCATION_CODE", 
		  "SHIP_TO_BUS_LOCATION_CODE_ID", 
		  "SHIP_TO_BUS_LOCATION_CODE",
		  "ROW_NO1")   
		 AS SELECT 
		  "EVENT_ID", 
		  "BIZLOC_UTC_TIME" , 
		  "BIZLOC_UTC_DATE" , 
		  "BIZLOC_TIME_OFFSET" , 
		  "BIZLOC_LOCAL_TIME" , 
		  "BIZLOC_LOCAL_DATE" , 
		  "INVENTORY_TIME_OFFSET" , 
		  "INVENTORY_LOCAL_TIME" , 
		  "INVENTORY_LOCAL_DATE" , 
		  "RECORDTIME",
		  "PRODUCT_ID",
		  "ASSET_NAME",
		  "EPC",
		  "ACTION_ID",
		  "ACTION",
		  "BIZSTEP_ID",
		  "BIZSTEP",
		  "DISPOSITION_ID",
		  "DISPOSITION",
		  "READ_POINT_ID",
		  "READ_POINT",
		  "BIZ_LOCATION_ID",
		  "BIZ_LOCATION",
		  "INVENTORY_LOCATION_ID",
		  "INVENTORY_LOCATION",
		  "SHIP_FROM_BUS_LOCATION_CODE_ID", 
		  "SHIP_FROM_BUS_LOCATION_CODE", 
		  "SHIP_TO_BUS_LOCATION_CODE_ID", 
		  "SHIP_TO_BUS_LOCATION_CODE",
		  "ROW_NO1"
            FROM RCMSCHEMA.EVENTEPC; 



--
-- RCMSCHEMA.CURRENT_EVENT_EPC_VW
--

CREATE  VIEW  "RCMSCHEMA"."CURRENT_EVENT_EPC_VW" (
		  "ASSET_NAME",
		  "PRODUCT_ID",
		  "EPC",
		  "BIZLOC_UTC_TIME" ,
		  "BIZLOC_UTC_DATE" ,
		  "BIZLOC_TIME_OFFSET" , 
		  "BIZLOC_LOCAL_TIME" , 
		  "BIZLOC_LOCAL_DATE" , 
		  "INVENTORY_TIME_OFFSET" , 
		  "INVENTORY_LOCAL_TIME" , 
		  "INVENTORY_LOCAL_DATE" , 
		  "INVENTORY_LOCATION_ID",
		  "DISPOSITION")
		AS SELECT
		  "ASSET_NAME",
		  "PRODUCT_ID",
		  "EPC",
		  "BIZLOC_UTC_TIME" ,
		  "BIZLOC_UTC_DATE" ,
		  "BIZLOC_TIME_OFFSET" , 
		  "BIZLOC_LOCAL_TIME" , 
		  "BIZLOC_LOCAL_DATE" , 
		  "INVENTORY_TIME_OFFSET" , 
		  "INVENTORY_LOCAL_TIME" , 
		  "INVENTORY_LOCAL_DATE" , 
		  "INVENTORY_LOCATION_ID",
		  "DISPOSITION"
		FROM "RCMSCHEMA"."CURRENT_EVENT_EPC";



--
-- RCMSCHEMA.RCM_METRICS_SNAPSHOT_UTC_VW
--

CREATE VIEW RCMSCHEMA.RCM_METRICS_SNAPSHOT_UTC_VW (
	"CREATE_DATE"  , 
	"LAST_UPDATE_DATE"  , 
	"PRODUCT_ID"  , 
	"LOCATION_ID"  , 
	"DATE_ID"  , 
	"CURRENT_INVENTORY"  , 
	"AGED_INVENTORY"  , 
	"TOTAL_INVENTORY"  , 
	"INVENTORY_ELAPSED_TIME"  , 
	"AGED_INVENTORY_ELAPSED_TIME"  , 
	"AVERAGE_AL_CYCLE_TIME"  , 
	"AVG_FAST_MOVING_AL_CYCLE_TIME"  , 
	"AVG_SLOW_MOVING_AL_CYCLE_TIME"  , 
	"AVERAGE_BP_CYCLE_TIME"  , 
	"AVG_FAST_MOVING_BP_CYCLE_TIME"  , 
	"AVG_SLOW_MOVING_BP_CYCLE_TIME"  , 
	"AVERAGE_DWELL_TIME"  , 
	"AVG_FAST_MOVING_DWELL_TIME"  , 
	"AVG_SLOW_MOVING_DWELL_TIME" )
	AS
	SELECT
		"CREATE_DATE"  , 
		"LAST_UPDATE_DATE"  , 
		"PRODUCT_ID"  , 
		"LOCATION_ID" , 
		"DATE_ID"  , 
		"CURRENT_INVENTORY" , 
		"AGED_INVENTORY" , 
		"TOTAL_INVENTORY" , 
		"INVENTORY_ELAPSED_TIME",
		"AGED_INVENTORY_ELAPSED_TIME" , 
		"AVERAGE_AL_CYCLE_TIME" , 
		"AVG_FAST_MOVING_AL_CYCLE_TIME" , 
		"AVG_SLOW_MOVING_AL_CYCLE_TIME" , 
		"AVERAGE_BP_CYCLE_TIME" , 
		"AVG_FAST_MOVING_BP_CYCLE_TIME" , 
		"AVG_SLOW_MOVING_BP_CYCLE_TIME" , 
		"AVERAGE_DWELL_TIME", 
		"AVG_FAST_MOVING_DWELL_TIME" , 
		"AVG_SLOW_MOVING_DWELL_TIME"
	FROM
		RCMSCHEMA.RCM_METRICS_SNAPSHOT_UTC;



--
-- RCMSCHEMA.RCM_METRICS_SNAPSHOT_LOCAL_VW
--

CREATE VIEW RCMSCHEMA.RCM_METRICS_SNAPSHOT_LOCAL_VW (
	"CREATE_DATE"  , 
	"LAST_UPDATE_DATE"  , 
	"PRODUCT_ID"  , 
	"LOCATION_ID"  , 
	"DATE_ID"  , 
	"CURRENT_INVENTORY"  , 
	"AGED_INVENTORY"  , 
	"TOTAL_INVENTORY"  , 
	"INVENTORY_ELAPSED_TIME"  , 
	"AGED_INVENTORY_ELAPSED_TIME"  , 
	"AVERAGE_AL_CYCLE_TIME"  , 
	"AVG_FAST_MOVING_AL_CYCLE_TIME"  , 
	"AVG_SLOW_MOVING_AL_CYCLE_TIME"  , 
	"AVERAGE_BP_CYCLE_TIME"  , 
	"AVG_FAST_MOVING_BP_CYCLE_TIME"  , 
	"AVG_SLOW_MOVING_BP_CYCLE_TIME"  , 
	"AVERAGE_DWELL_TIME"  , 
	"AVG_FAST_MOVING_DWELL_TIME"  , 
	"AVG_SLOW_MOVING_DWELL_TIME" )
	AS 
	SELECT
		"CREATE_DATE"  , 
		"LAST_UPDATE_DATE"  , 
		"PRODUCT_ID"  , 
		"LOCATION_ID" , 
		"DATE_ID"  , 
		"CURRENT_INVENTORY" , 
		"AGED_INVENTORY" , 
		"TOTAL_INVENTORY" , 
		"INVENTORY_ELAPSED_TIME",
		"AGED_INVENTORY_ELAPSED_TIME" , 
		"AVERAGE_AL_CYCLE_TIME" , 
		"AVG_FAST_MOVING_AL_CYCLE_TIME" , 
		"AVG_SLOW_MOVING_AL_CYCLE_TIME" , 
		"AVERAGE_BP_CYCLE_TIME" , 
		"AVG_FAST_MOVING_BP_CYCLE_TIME" , 
		"AVG_SLOW_MOVING_BP_CYCLE_TIME" , 
		"AVERAGE_DWELL_TIME", 
		"AVG_FAST_MOVING_DWELL_TIME" , 
		"AVG_SLOW_MOVING_DWELL_TIME"
	FROM
		RCMSCHEMA.RCM_METRICS_SNAPSHOT_LOCAL;


COMMIT WORK;
